# clear environment and load relevant libraries
rm(list=ls())
library(lme4)
library(lmerTest)

# load the data file (must be in the current directory)
Data = read.csv("Expt3_Data.csv")

# Deviation-code 3-level predictor with SpeechType = NS (narrative) as intercept reference, and 2-level predictor AttachmentType
Data$DS = scale(ifelse(Data$SpeechType=="DS",1,0),scale=F)
Data$IS = scale(ifelse(Data$SpeechType=="IS",1,0),scale=F)
Data$Att = scale(ifelse(Data$AttachmentType=="LA",1,0),scale=F)

# fitting a lmm of readability rating
m.rating = lmer(ReadabilityRating ~ DS*Att + IS*Att + (1 + DS*Att + IS*Att||Subj) + (1 + DS*Att + IS*Att||Item), data = Data)
summary(m.rating)

# percentages of pauses
descriptive <- aggregate(. ~ SpeechType*AttachmentType, Data, function(x) c(M = mean(x), SE = sd(x)/sqrt(length(x))))
descriptive[,6:8]

# binary logistic model of BeforeSpeech pause occurrences
m1 <- glmer(Pause_BeforeSpeech ~ DS*Att + IS*Att + (0 + DS*Att + IS*Att || Subj) + (0 + DS*Att + IS*Att || Item),
            data=Data, family=binomial(logit), control = glmerControl(optCtrl=list(maxfun=50000), tol = .0001))
summary(m1)

# binary logistic model of After NP1 pause occurrences
m2 <- glmer(Pause_AfterNP1 ~ DS*Att + IS*Att + (0 + DS*Att + IS*Att || Subj) + (0 + DS*Att + IS*Att || Item),
            data=Data, family=binomial(logit), control = glmerControl(optCtrl=list(maxfun=50000), tol = .0001))
summary(m2)

# binary logistic model of After NP2 pause occurrences
m3 <- glmer(Pause_AfterNP2 ~ DS*Att + IS*Att + (0 + DS*Att + IS*Att || Subj) + (0 + DS*Att + IS*Att || Item),
            data=Data, family=binomial(logit), control = glmerControl(optCtrl=list(maxfun=50000), tol = .0001))
summary(m3)

# End of script